##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~##
# Nest survival simulation
# Effect of monitoring interval on SE
# Last updated 04-17-2017
##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~##

##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~##
#### Section 1: Describe simulation ####
##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~##

# Below is a modified version of the nest simulation modeling code published at http://dan-gibson.weebly.com/nest-survival-simulation.html
# a version of which was originally presented in Gibson et al. 2016.  doi: 10.1002/ece3.2148
# The premise behind the simulation is that iButton thermal dataloggers allow a 1-day or less visit frequency,
# which allows for improved precision of the estimate of Daily Survival Rate in Program MARK
# This analysis was fit using Program MARK with the RMark package
# The original code that was provided on Dan Gibson's website was modified for this project by Matt Stephenson and Dr. Robert Klaver


##~~~~~~~~~~~~~~~~~~~~~~##
#### Set up workspace ####
##~~~~~~~~~~~~~~~~~~~~~~##

require(RMark)
require(plyr)
require(reshape)
require(reshape2)
require(data.table)
require(dplyr)
library(ggplot2)
library(extrafont)

# The simulation is currently set for an initial sample sizes of 100 nests
# Modify the mod.occ and n variables to adjust initial sample size

# Using a similar number of nests to the real-world nest dataset seems appropriate

sim.nsurviv <- function() {
    #Specify number of occasions
    n.occasions<-80
    #Modify the number of occasions for other lengths
    mod.occ <- 60
    #Specify the nesting period
    nest.period<-12    
    #Define nest initiation rates
    n = 5
    #Release the individuals
    n.marked<-c(rep(n,n.occasions-mod.occ), rep(0,n,n.occasions-mod.occ))
    n.indiv<-sum(n.marked)
    nest.init<-rep(1:10, each = n)
    logit<-function(p) log(p/(1-p))
    expit<-function(x) 1/(1+exp(-x))

    #Define nest survival as a constant function (dot model)
    S0 <- 0.91
    b0<-logit(S0)
    p<-rep(1,n.occasions-1)
    S<-expit(b0)

    # Create the 'truth' scenario
    simul.pos<-function(Phi,P,n.marked)
    {
      Phi<-matrix(S,n.occasions,nrow=n.indiv,byrow=FALSE)
      n.occasions<-length(p)+1
      P<-matrix(p,n.occasions-1,nrow=n.indiv,byrow=T)
      CH<-matrix(0,ncol=n.occasions,nrow=sum(n.marked))
      #define a vector with marking occasion
      mark.occ<-rep(1:length(n.marked),n.marked[1:length(n.marked)])
      #fill in CH
      for (i in 1:sum(n.marked))
      {
        CH[i,mark.occ[i]]<-1
        if (mark.occ[i]==n.occasions) next
        for(t in (mark.occ[i]+1):n.occasions)
        {
          #survive?
          sur<-rbinom(1,1,Phi[i,t-1])
          if(sur==0) break #move to next
          #recaptured?
          rp<-rbinom(1,1,P[i,t-1])
          if(rp==1) CH[i,t]<-1
        } #t
      } #i
      return(CH)
    }

    ## function to create capture history character strings (need for input to RMARK)
    pasty<-function(x)
    {
      k<-ncol(x)
      n<-nrow(x)
      out<-array(dim=n)
      for (i in 1:n)
      {
        out[i]<-paste(x[i,],collapse="")
      }
      return(out)
    }

    #Simulate a run
    sim.nests<-simul.pos(Phi,P,n.marked)
    n.ind <- sum(n.marked)
    encounter.history<-matrix(ncol = n.occasions, nrow = n.ind)
    nest.init<-rep(1:(n.occasions-mod.occ), each = n)
    # allow nests to hatch
    hatch <- nest.period
    for(i in 1:n.ind){
      for(j in 1:n.occasions){
        if(sum(sim.nests[i,1:j]) > hatch) {
          encounter.history[i,j] <- 0 } else {
            encounter.history[i,j] <- sim.nests[i,j]
          }
      }
    }

# Define how often observers check nests, once at a coarse scale and once at a fine scale
# Switch inputs by commenting on/off in 3 places in 'coarse' and 1 place in 'fine' (sorry, I was young)

##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~##
#### Coarse scale visitation ####
##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~##
    
##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ 
    # 2 day schedule
#    visit.history.c <- encounter.history
#    for(i in 1:n.ind){
#      for(j in 1:(n.occasions-nest.period+1)){
#        if(encounter.history[i,j] == 1 & visit.history.c[i,j] == 1 & visit.history.c[i,j+(nest.period-1)] == 1){
#          visit.history.c[i,j+1]<-0
#          visit.history.c[i,j+3]<-0
#          visit.history.c[i,j+5]<-0
#          visit.history.c[i,j+7]<-0
#          visit.history.c[i,j+8]<-0
#          visit.history.c[i,j+10]<-0
#        }
#        else
#        if(encounter.history[i,j] == 1 & visit.history.c[i,j] == 1 & length(which(encounter.history[i,]==1)) != nest.period){
#           visit.history.c[i,j+1]<-0
#        }
#      }
#    }
##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~   
    # 3 day schedule
#    visit.history.c <- encounter.history
#    for(i in 1:n.ind){
#      for(j in 1:(n.occasions-nest.period+1)){
#        if(encounter.history[i,j] == 1 & visit.history.c[i,j] == 1 & visit.history.c[i,j+(nest.period-1)] == 1){
#          visit.history.c[i,j+1]<-0
#          visit.history.c[i,j+2]<-0
#          visit.history.c[i,j+4]<-0
#          visit.history.c[i,j+5]<-0
#          visit.history.c[i,j+7]<-0
#          visit.history.c[i,j+8]<-0
#          visit.history.c[i,j+10]<-0
#        }
#        else
#        if(encounter.history[i,j] == 1 & visit.history.c[i,j] == 1 & length(which(encounter.history[i,]==1)) != nest.period){
#           visit.history.c[i,j+1]<-0
#           visit.history.c[i,j+2]<-0
#        }
#      }
#    }
##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~   
    # 4 day schedule
    visit.history.c <- encounter.history
    for(i in 1:n.ind){
      for(j in 1:(n.occasions-nest.period+1)){
        if(encounter.history[i,j] == 1 & visit.history.c[i,j] == 1 & visit.history.c[i,j+(nest.period-1)] == 1){
          visit.history.c[i,j+1]<-0
          visit.history.c[i,j+2]<-0
          visit.history.c[i,j+3]<-0
          visit.history.c[i,j+5]<-0
          visit.history.c[i,j+6]<-0
          visit.history.c[i,j+7]<-0
          visit.history.c[i,j+9]<-0
          visit.history.c[i,j+10]<-0
        }
        else
        if(encounter.history[i,j] == 1 & visit.history.c[i,j] == 1 & length(which(encounter.history[i,]==1)) != nest.period){
           visit.history.c[i,j+1]<-0
           visit.history.c[i,j+2]<-0
           visit.history.c[i,j+3]<-0
        }
      }
    }
##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ 
    # 5 day schedule
#    visit.history.c <- encounter.history
#    for(i in 1:n.ind){
#      for(j in 1:(n.occasions-nest.period+1)){
#        if(encounter.history[i,j] == 1 & visit.history.c[i,j] == 1 & visit.history.c[i,j+(nest.period-1)] == 1){
#          visit.history.c[i,j+1]<-0
#          visit.history.c[i,j+2]<-0
#          visit.history.c[i,j+3]<-0
#          visit.history.c[i,j+4]<-0
#          visit.history.c[i,j+6]<-0
#          visit.history.c[i,j+7]<-0
#          visit.history.c[i,j+8]<-0
#          visit.history.c[i,j+9]<-0
#          visit.history.c[i,j+10]<-0
#        }
#        else
#          if(encounter.history[i,j] == 1 & visit.history.c[i,j] == 1 & length(which(encounter.history[i,]==1)) != nest.period){
#            visit.history.c[i,j+1]<-0
#            visit.history.c[i,j+2]<-0
#            visit.history.c[i,j+3]<-0
#            visit.history.c[i,j+4]<-0
#          }
#      }
#    }
##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ 
    # 6 day schedule
#    visit.history.c <- encounter.history
#    for(i in 1:n.ind){
#      for(j in 1:(n.occasions-nest.period+1)){
#        if(encounter.history[i,j] == 1 & visit.history.c[i,j] == 1 & visit.history.c[i,j+(nest.period-1)] == 1){
#          visit.history.c[i,j+1]<-0
#          visit.history.c[i,j+2]<-0
#          visit.history.c[i,j+3]<-0
#          visit.history.c[i,j+4]<-0
#          visit.history.c[i,j+5]<-0
#          visit.history.c[i,j+7]<-0
#          visit.history.c[i,j+8]<-0
#          visit.history.c[i,j+9]<-0
#          visit.history.c[i,j+10]<-0
#        }
#        else
#          if(encounter.history[i,j] == 1 & visit.history.c[i,j] == 1 & length(which(encounter.history[i,]==1)) != nest.period){
#            visit.history.c[i,j+1]<-0
#            visit.history.c[i,j+2]<-0
#            visit.history.c[i,j+3]<-0
#            visit.history.c[i,j+4]<-0
#            visit.history.c[i,j+5]<-0
#          }
#      }
#    }
##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~   
    # 7 day schedule
#    visit.history.c <- encounter.history
#    for(i in 1:n.ind){
#      for(j in 1:(n.occasions-nest.period+1)){
#        if(encounter.history[i,j] == 1 & visit.history.c[i,j] == 1 & visit.history.c[i,j+(nest.period-1)] == 1){
#          visit.history.c[i,j+1]<-0
#          visit.history.c[i,j+2]<-0
#          visit.history.c[i,j+3]<-0
#          visit.history.c[i,j+4]<-0
#          visit.history.c[i,j+5]<-0
#          visit.history.c[i,j+6]<-0
#          visit.history.c[i,j+8]<-0
#          visit.history.c[i,j+9]<-0
#          visit.history.c[i,j+10]<-0
#        }
#        else
#          if(encounter.history[i,j] == 1 & visit.history.c[i,j] == 1 & length(which(encounter.history[i,]==1)) != nest.period){
#            visit.history.c[i,j+1]<-0
#            visit.history.c[i,j+2]<-0
#            visit.history.c[i,j+3]<-0
#            visit.history.c[i,j+4]<-0
#            visit.history.c[i,j+5]<-0
#            visit.history.c[i,j+6]<-0
#          }
#      }
#    }

    
##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ 
    #Create a matrix of detection dates
    det.prob <- 0.75
    DH<-matrix(0,ncol=n.occasions,nrow=sum(n.marked))
    for(i in 1:sum(n.marked)){
      for(j in 1:n.occasions){
        detected<-rbinom(1,1,det.prob)
        if(visit.history.c[i,j] == 1 & detected==1){
          DH[i,j] <- 1
        }
      }
    }
    #Incoporate detection probabilities
    DayFound<-matrix(nrow = n.ind, ncol = 1)
    for(i in 1:n.ind){
        if(rowSums(DH)[i] == 0){
          DayFound[i] <- 0
        }
        else{
          DayFound[i] <- which.max(DH[i,])
          }
        }

    #Need to ensure nests are discovered on a vist day so they don't get credit for being observed before being discovered
    FirstFound<-DayFound
##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~    
    # 2 day schedule
#    for(i in 1:n.ind){
#      FirstFound[i] <- FirstFound[i] - nest.init[i] + 1
#    }
#    for(i in 1:n.ind){
#      if(FirstFound[i] < 1 | FirstFound[i] >= 13){
#        FirstFound[i] <- NA
#      }
#    }
##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ 
    # 3 day schedule
#    for(i in 1:n.ind){
#      FirstFound[i] <- FirstFound[i] - nest.init[i] + 1
#    }
#    for(i in 1:n.ind){
#      if(FirstFound[i] > 1 & FirstFound[i] < 4){
#        FirstFound[i] <- 4
#      }
#      if(FirstFound[i] > 4 & FirstFound[i] < 7){
#        FirstFound[i] <- 7
#      }
#      if(FirstFound[i] > 7 & FirstFound[i] < 10){
#        FirstFound[i] <- 10
#      }
#      if(FirstFound[i] > 10 & FirstFound[i] < 13){
#        FirstFound[i] <- 12
#      }
#      if(FirstFound[i] < 1 | FirstFound[i] >= 13){
#        FirstFound[i] <- NA
#      }
#    }
##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~    
    # 4 day schedule
    for(i in 1:n.ind){
      FirstFound[i] <- FirstFound[i] - nest.init[i] + 1
    }
    for(i in 1:n.ind){
      if(FirstFound[i] > 1 & FirstFound[i] < 5){
        FirstFound[i] <- 5
      }
      if(FirstFound[i] > 5 & FirstFound[i] < 9){
        FirstFound[i] <- 9
      }
      if(FirstFound[i] > 9 & FirstFound[i] < 12){
        FirstFound[i] <- 12
      }
      if(FirstFound[i] < 1 | FirstFound[i] >= 13){
        FirstFound[i] <- NA
      }
    }
##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~  
    # 5 day schedule
#    for(i in 1:n.ind){
#      FirstFound[i] <- FirstFound[i] - nest.init[i] + 1
#    }
#    for(i in 1:n.ind){
#      if(FirstFound[i] > 1 & FirstFound[i] < 6){
#        FirstFound[i] <- 6
#      }
#      if(FirstFound[i] > 6 & FirstFound[i] < 11){
#        FirstFound[i] <- 11
#      }
#      if(FirstFound[i] > 11 & FirstFound[i] < 16){
#        FirstFound[i] <- 16
#      }
#      if(FirstFound[i] < 1 | FirstFound[i] >= 13){
#        FirstFound[i] <- NA
#      }
#    }
##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ 
    # 6 day schedule
#    for(i in 1:n.ind){
#      FirstFound[i] <- FirstFound[i] - nest.init[i] + 1
#    }
#    for(i in 1:n.ind){
#      if(FirstFound[i] > 1 & FirstFound[i] < 8){
#        FirstFound[i] <- 7
#      }
#      if(FirstFound[i] > 8 & FirstFound[i] < 13){
#        FirstFound[i] <- 13
#      }
#      if(FirstFound[i] < 1 | FirstFound[i] >= 13){
#        FirstFound[i] <- NA
#      }
#    }
##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~    
    # 7 day schedule
#    for(i in 1:n.ind){
#      FirstFound[i] <- FirstFound[i] - nest.init[i] + 1
#    }
#    for(i in 1:n.ind){
#      if(FirstFound[i] > 1 & FirstFound[i] < 8){
#        FirstFound[i] <- 8
#      }
#      if(FirstFound[i] > 9 & FirstFound[i] < 13){
#        FirstFound[i] <- 15
#      }
#      if(FirstFound[i] < 1 | FirstFound[i] >= 13){
#        FirstFound[i] <- NA
#      }
#    }

##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ 
    row.sums <- apply(visit.history.c, 1, sum)
    KnownAlive<-matrix(nrow = n.ind, ncol = 1)
    for(i in 1:n.ind){
      if(row.sums[i] > 0){ #changed from 1 to 0
        KnownAlive[i]<- tail(which(visit.history.c[i,] == 1), n=1)
      } else{
        KnownAlive[i] <- NA
      }}
    LastAlive<-KnownAlive - nest.init + 1
    #Hatched nests terminate at fate date, failed nests terminate after being
    #  detected, which is 1-6 days post-failure, depending on visit interval
    LastCheck<-matrix(nrow = n.ind, ncol = 1)
    daysactive <- max.col(visit.history.c, ties.method = "last") - max.col(visit.history.c, ties.method = "first") + 1
    Fate<-matrix(nrow = n.ind, ncol = 1)
    for(i in 1:n.ind){
      if(daysactive[i] == nest.period) {
        Fate[i] <-0}
      else{
        Fate[i] <-1}
    }
##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ 
    # 2 day schedule
#    for(i in 1:n.ind){
#      if(Fate[i] == 0) {LastCheck[i] <- hatch}
#      else
#      if(Fate[i] == 1 & daysactive[i] == 11) {LastCheck[i] <- hatch}
#      else{LastCheck[i]<- daysactive[i] + 2}
#    }
    # 3 day schedule
#    for(i in 1:n.ind){
#      if(Fate[i] == 0) {LastCheck[i] <- hatch}
#      else
#      if(Fate[i] == 1 & daysactive[i] == 10) {LastCheck[i] <- hatch}
#      else{LastCheck[i]<- daysactive[i] + 3}
#    }
    # 4 day schedule
    for(i in 1:n.ind){
      if(Fate[i] == 0) {LastCheck[i] <- hatch}
      if(Fate[i] == 1 & daysactive[i] == 1) {LastCheck[i] <- 5}
      if(Fate[i] == 1 & daysactive[i] == 5) {LastCheck[i] <- 9}
      if(Fate[i] == 1 & daysactive[i] == 9) {LastCheck[i] <- 12}
    }
    # 5 day schedule
#    for(i in 1:n.ind){
#      if(Fate[i] == 0) {LastCheck[i] <- hatch}
#      if(Fate[i] == 1 & daysactive[i] == 1) {LastCheck[i] <- 6}
#      if(Fate[i] == 1 & daysactive[i] == 6) {LastCheck[i] <- 11}
#      if(Fate[i] == 1 & daysactive[i] == 11) {LastCheck[i] <- hatch}
#    }
    # 6 day schedule
#    for(i in 1:n.ind){
#      if(Fate[i] == 0) {LastCheck[i] <- hatch}
#      if(Fate[i] == 1 & daysactive[i] == 1) {LastCheck[i] <- 7}
#      if(Fate[i] == 1 & daysactive[i] == 7) {LastCheck[i] <- hatch}
#    }
    # 7 day schedule
#    for(i in 1:n.ind){
#      if(Fate[i] == 0) {LastCheck[i] <- hatch}
#      if(Fate[i] == 1 & daysactive[i] == 1) {LastCheck[i] <- 8}
#      if(Fate[i] == 1 & daysactive[i] == 8) {LastCheck[i] <- hatch}
#    }
    
##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~   
    for(i in 1:n.ind){
      if(LastCheck[i]>hatch) {LastCheck[i] <- hatch}
    }
    Freq<-matrix(1, nrow = n.ind, ncol = 1)
    
    sim.data.c<-as.data.frame(cbind(FirstFound, LastAlive,LastCheck,Fate,Freq))
    names(sim.data.c)<-c("FirstFound","LastPresent","LastChecked","Fate",  "Freq")
    sim.data.c <- sim.data.c[sim.data.c$FirstFound <= sim.data.c$LastPresent,] #Removing nests that were not found prior to discovery
    sim.data.c <- sim.data.c[!is.na(sim.data.c$FirstFound),] 
    
##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~##
#### Fine (1 day) visitation ####
##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~##
    
    observer.effort.f<-1
    visit.history.f <- encounter.history
    for(i in 1:n.ind){
      for(j in 1:n.occasions){
        if(encounter.history[i,j] == 1){visit.history.f[i,j]<-rbinom(visit.history.f[i,j], 1, observer.effort.f)}
      }}
    #Incoporate random aspect of nest detection
    DayFound<-matrix(nrow = n.ind, ncol = 1)
    for(i in 1:n.ind){
      if(rowSums(DH)[i] == 0){
        DayFound[i] <- 0
      }
      else{
        DayFound[i] <- which.max(DH[i,])
      }
    }
    #Need to ensure nests are discovered on a vist day so they don't get credit for being observed before being discovered
##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # 2 day schedule
#    FirstFound<-DayFound
#    for(i in 1:n.ind){
#      FirstFound[i] <- FirstFound[i] - nest.init[i] + 1
#    }
#    for(i in 1:n.ind){
#      if(FirstFound[i] < 1 | FirstFound[i] >= 13){
#        FirstFound[i] <- NA
#      }
#    }
##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # 3 day schedule
#    FirstFound<-DayFound
#    for(i in 1:n.ind){
#      FirstFound[i] <- FirstFound[i] - nest.init[i] + 1
#    }
#    for(i in 1:n.ind){
#      if(FirstFound[i] > 1 & FirstFound[i] < 4){
#        FirstFound[i] <- 4
#      }
#      if(FirstFound[i] > 4 & FirstFound[i] < 7){
#        FirstFound[i] <- 7
#      }
#      if(FirstFound[i] > 7 & FirstFound[i] < 10){
#        FirstFound[i] <- 10
#      }
#      if(FirstFound[i] > 10 & FirstFound[i] < 13){
#        FirstFound[i] <- 12
#      }
#      if(FirstFound[i] < 1 | FirstFound[i] >= 13){
#        FirstFound[i] <- NA
#      }
#    }
##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~  
    # 4 day schedule
    FirstFound<-DayFound
    for(i in 1:n.ind){
      FirstFound[i] <- FirstFound[i] - nest.init[i] + 1
    }
    for(i in 1:n.ind){
      if(FirstFound[i] > 1 & FirstFound[i] < 5){
        FirstFound[i] <- 5
      }
      if(FirstFound[i] > 5 & FirstFound[i] < 9){
        FirstFound[i] <- 9
      }
      if(FirstFound[i] > 9 & FirstFound[i] < 12){
        FirstFound[i] <- 12
      }
      if(FirstFound[i] < 1 | FirstFound[i] >= 13){
        FirstFound[i] <- NA
      }
    }
##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ 
    # 5 day schedule
#    FirstFound<-DayFound
#    for(i in 1:n.ind){
#      FirstFound[i] <- FirstFound[i] - nest.init[i] + 1
#    }
#    for(i in 1:n.ind){
#      if(FirstFound[i] > 1 & FirstFound[i] < 6){
#        FirstFound[i] <- 6
#      }
#      if(FirstFound[i] > 6 & FirstFound[i] < 11){
#        FirstFound[i] <- 11
#      }
#      if(FirstFound[i] > 11 & FirstFound[i] < 16){
#        FirstFound[i] <- 16
#      }
#      if(FirstFound[i] < 1 | FirstFound[i] >= 13){
#        FirstFound[i] <- NA
#      }
#    }
##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~  
    # 6 day schedule
#    FirstFound<-DayFound
#    for(i in 1:n.ind){
#      FirstFound[i] <- FirstFound[i] - nest.init[i] + 1
#    }
#    for(i in 1:n.ind){
#      if(FirstFound[i] > 1 & FirstFound[i] < 8){
#        FirstFound[i] <- 7
#      }
#      if(FirstFound[i] > 8 & FirstFound[i] < 13){
#        FirstFound[i] <- 13
#      }
#      if(FirstFound[i] < 1 | FirstFound[i] >= 13){
#        FirstFound[i] <- NA
#      }
#    }
##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~   
    # 7 day schedule
#    FirstFound<-DayFound
#    for(i in 1:n.ind){
#      FirstFound[i] <- FirstFound[i] - nest.init[i] + 1
#    }
#    for(i in 1:n.ind){
#      if(FirstFound[i] > 1 & FirstFound[i] < 8){
#        FirstFound[i] <- 8
#      }
#      if(FirstFound[i] > 9 & FirstFound[i] < 13){
#        FirstFound[i] <- 13
#      }
#      if(FirstFound[i] < 1 | FirstFound[i] >= 13){
#        FirstFound[i] <- NA
#      }
#    }
##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    row.sums <- apply(visit.history.f, 1, sum)
    KnownAlive<-matrix(nrow = n.ind, ncol = 1)
    for(i in 1:n.ind){
      if(row.sums[i] > 0){ #changed from 1 to 0
        KnownAlive[i]<- tail(which(visit.history.f[i,] == 1), n=1)
      } else{
        KnownAlive[i] <- NA
      }}
    LastAlive<-KnownAlive - nest.init + 1
    #Hatched nests terminate at fate date, failed nests terminate after being
    #  detected, which at this resolution is always 1 day post-failure
    LastCheck<-matrix(nrow = n.ind, ncol = 1)
    ObserverEffort.f<-matrix(sample(1:1, size = nrow(encounter.history)*1, replace = TRUE), nrow = nrow(encounter.history), ncol = 1) #Adjust sample frame
    daysactive <- max.col(visit.history.f, ties.method = "last") - max.col(visit.history.f, ties.method = "first") + 1
    Fate<-matrix(nrow = n.ind, ncol = 1)
    for(i in 1:n.ind){
      if(daysactive[i] == nest.period) {
        Fate[i] <-0}
      else{
        Fate[i] <-1}
    }
    for(i in 1:n.ind){
      if(Fate[i] == 0) {LastCheck[i] <- hatch}
      else{
        LastCheck[i]<- daysactive[i] + ObserverEffort.f[i]}
    }
    for(i in 1:n.ind){
      if(LastCheck[i]>hatch) {LastCheck[i] <- hatch}
    }
    Freq<-matrix(1, nrow = n.ind, ncol = 1)
    
    sim.data.f<-as.data.frame(cbind(FirstFound, LastAlive,LastCheck,Fate,Freq))
    names(sim.data.f)<-c("FirstFound","LastPresent","LastChecked","Fate",  "Freq")
    sim.data.f <- sim.data.f[sim.data.f$FirstFound <= sim.data.f$LastPresent,] #Removing nests that were not found prior to discovery
    sim.data.f <- sim.data.f[!is.na(sim.data.f$FirstFound),] 
    
##~~~~~~~~~~~~~~##    
#### Run MARK ####
##~~~~~~~~~~~~~~##
    DotCoarse=mark(sim.data.c, nocc=nest.period, model="Nest", output=FALSE,
                   model.parameters=list(S=list(formula=~1)))
    
    est.c <- DotCoarse$results$real[1]
    se.c <-  DotCoarse$results$real[2]
    n <-   DotCoarse$results$n
    coarse <- cbind(est.c, se.c, n)
    coarse$resolution <- "coarse"
    
    DotFine=mark(sim.data.f, nocc=nest.period, model="Nest", output=FALSE,
                 model.parameters=list(S=list(formula=~1)))
    
    est.f <- DotFine$results$real[1]
    se.f <-  DotFine$results$real[2]
    n <-   DotFine$results$n
    fine <- cbind(est.f, se.f, n)
    fine$resolution <- "fine"
    
    result <- rbind(fine, coarse)
    
    return(result)
    
}

#Create ouputs for fine and coarse visit schedules
output.f <- data.frame(sim=NA, estimate=NA, se=NA, n=NA)
output.c <- data.frame(sim=NA, estimate=NA, se=NA, n=NA)

start.time <- Sys.time()

for(i in 1:20) {
  mysim <- sim.nsurviv()
  output.f[i,"sim"] <- i                #simulation rep
  output.f[i,"estimate"] <- mysim[1,1]  #DSR estimate (fine)
  output.f[i,"se"] <- mysim[1,2]        #SE (fine)
  output.f[i,"n"] <- mysim[1,3]         #n (fine)
  output.c[i,"sim"] <- i                #simulation rep
  output.c[i,"estimate"] <- mysim[2,1]  #DSR estimate (coarse)
  output.c[i,"se"] <- mysim[2,2]        #SE estimate (coarse)
  output.c[i,"n"] <- mysim[2,3]         #n (coarse)
}

end.time <- Sys.time()
time.taken <- end.time - start.time
time.taken

output.f$scale <- 'fine'
output.c$scale <- 'coarse'
output.combined <- rbind(output.f, output.c)
output.combined$Err2 <- (output.combined$estimate - 0.91)^2
output.combined$MSE[output.combined$scale=="fine"] <- mean(output.combined$Err2[output.combined$scale=="fine"])
output.combined$MSE[output.combined$scale=="coarse"] <- mean(output.combined$Err2[output.combined$scale=="coarse"])
output.combined$var[output.combined$scale=="fine"] <- var(output.combined$estimate[output.combined$scale=="fine"])
output.combined$var[output.combined$scale=="coarse"] <- var(output.combined$estimate[output.combined$scale=="coarse"])
output.combined$se2 <- output.combined$se^2
output.combined$bias <- output.combined$estimate - 0.91

names(output.combined)[names(output.combined)=="scale"] <- "Scale"

# write.csv(output.combined, "sim output 100n dsr91 10000 nests 2 day.csv", row.names=F)
# write.csv(output.combined, "sim output 100n dsr91 10000 nests 3 day.csv", row.names=F)
# write.csv(output.combined, "sim output 100n dsr91 10000 nests 4 day.csv", row.names=F)
# write.csv(output.combined, "sim output 100n dsr91 10000 nests 5 day.csv", row.names=F)
# write.csv(output.combined, "sim output 100n dsr91 10000 nests 6 day.csv", row.names=F)
# write.csv(output.combined, "sim output 100n dsr91 10000 nests 7 day.csv", row.names=F)
# 
# output.combined <- read.csv("sim output 40n dsr91 10000 nests 2 day.csv", header=T)
# output.combined <- read.csv("sim output 40n dsr91 10000 nests 3 day.csv", header=T)
# output.combined <- read.csv("sim output 40n dsr91 10000 nests 4 day.csv", header=T)
# output.combined <- read.csv("sim output 40n dsr91 10000 nests 5 day.csv", header=T)
# output.combined <- read.csv("sim output 40n dsr91 10000 nests 6 day.csv", header=T)
# output.combined <- read.csv("sim output 40n dsr91 10000 nests 7 day.csv", header=T)
# 
# output.combined <- read.csv("sim output 100n dsr91 10000 nests 2 day.csv", header=T)
# output.combined <- read.csv("sim output 100n dsr91 10000 nests 3 day.csv", header=T)
output.combined <- read.csv("sim output 100n dsr91 10000 nests 4 day.csv", header=T)
# output.combined <- read.csv("sim output 100n dsr91 10000 nests 5 day.csv", header=T)
# output.combined <- read.csv("sim output 100n dsr91 10000 nests 6 day.csv", header=T)
# output.combined <- read.csv("sim output 100n dsr91 10000 nests 7 day.csv", header=T)
# 
# output.combined <- read.csv("sim output 400n dsr91 10000 nests 2 day.csv", header=T)
# output.combined <- read.csv("sim output 400n dsr91 10000 nests 3 day.csv", header=T)
# output.combined <- read.csv("sim output 400n dsr91 10000 nests 4 day.csv", header=T)
# output.combined <- read.csv("sim output 400n dsr91 10000 nests 5 day.csv", header=T)
# output.combined <- read.csv("sim output 400n dsr91 10000 nests 6 day.csv", header=T)
# output.combined <- read.csv("sim output 400n dsr91 10000 nests 7 day.csv", header=T)

##~~~~~~~~~~~~~~~~~~~~~~~~~~##
#### Graphing the Results ####
##~~~~~~~~~~~~~~~~~~~~~~~~~~##

library(ggplot2)
library(extrafont)
loadfonts(device="win")

plot.dsr <- ggplot(output.combined, aes(estimate, fill = Scale)) + 
              geom_histogram(alpha = 0.7, position = 'identity') +
              scale_fill_manual(values=c("#C8102E", "#F1BE48")) +
              geom_vline(xintercept=0.91, linetype="dashed") +
              xlab("Daily survival rate") +
              ylab("Count") +
              ggtitle("Daily survival rate estimate") +
              theme(plot.title=element_text(hjust=0.5), text=element_text(size=18)) +
              theme(legend.position="none") +
              theme(legend.position = c(0.9, 0.9)) 
plot.dsr

plot.n <- ggplot(output.combined, aes(n, fill = Scale)) + 
            geom_histogram(alpha = 0.7, position = 'identity') +
            scale_fill_manual(values=c("#C8102E", "#F1BE48")) +
            ggtitle("Sample size") +
            labs(x="Nest observation-days", y="Count") +
            theme(text=element_text(family="Times New Roman", size=12))+
            theme(plot.title=element_text(hjust=0.5), text=element_text(size=12)) +
            theme(legend.position="none") +
            theme(legend.position = c(0.13, 0.69)) +
            theme(legend.title=element_text(size=10), legend.text=element_text(size=10)) #+
            #annotate("text", label="A", family="Times New Roman", x=2000, y=720, size=8)
plot.n

plot.se <- ggplot(output.combined, aes(se, fill = Scale)) + 
  geom_histogram(alpha = 0.8, position = 'identity') +
  scale_fill_manual(values=c("#C8102E", "#F1BE48")) +
  ggtitle("Standard error") +
  labs(x="SE", y="Count") +
  theme(text=element_text(family="Times New Roman", size=12))+
  theme(plot.title=element_text(hjust=0.5), text=element_text(size=12)) +
  annotate("text", label="B", family="Times New Roman", x=.00475, y=590, size=8)+
  guides(fill=FALSE)

plot.se



##~~~~~~~~~~~~~~~~~~~~~~~~~~~~##
#### Multiple plot function ####
##~~~~~~~~~~~~~~~~~~~~~~~~~~~~##

# ggplot objects can be passed in ..., or to plotlist (as a list of ggplot objects)
# - cols:   Number of columns in layout
# - layout: A matrix specifying the layout. If present, 'cols' is ignored.
#
# If the layout is something like matrix(c(1,2,3,3), nrow=2, byrow=TRUE),
# then plot 1 will go in the upper left, 2 will go in the upper right, and
# 3 will go all the way across the bottom.
#
multiplot <- function(..., plotlist=NULL, file, cols=1, layout=NULL) {
  library(grid)
  
  # Make a list from the ... arguments and plotlist
  plots <- c(list(...), plotlist)
  
  numPlots = length(plots)
  
  # If layout is NULL, then use 'cols' to determine layout
  if (is.null(layout)) {
    # Make the panel
    # ncol: Number of columns of plots
    # nrow: Number of rows needed, calculated from # of cols
    layout <- matrix(seq(1, cols * ceiling(numPlots/cols)),
                     ncol = cols, nrow = ceiling(numPlots/cols))
  }
  
  if (numPlots==1) {
    print(plots[[1]])
    
  } else {
    # Set up the page
    grid.newpage()
    pushViewport(viewport(layout = grid.layout(nrow(layout), ncol(layout))))
    
    # Make each plot, in the correct location
    for (i in 1:numPlots) {
      # Get the i,j matrix positions of the regions that contain this subplot
      matchidx <- as.data.frame(which(layout == i, arr.ind = TRUE))
      
      print(plots[[i]], vp = viewport(layout.pos.row = matchidx$row,
                                      layout.pos.col = matchidx$col))
    }
  }
}

# ggsave("Figure 3.png", plot=multiplot(plot.n, plot.se, cols=2), device='png', width=6.25, height=3.125)

##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~##
#### Graphing SE by visit interval ####
##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~##

library(ggplot2)
library(extrafont)
#font_import() #should just be once per machine
loadfonts(device="win")

ses <- read.csv("Sim Standard Errors.csv", header=T) #Results from different combinations of visit interval and starting nest number are stored in a .csv file
ses$Nests <- as.factor(ses$Nests)
ses$Interval <- as.numeric(ses$Interval)

real <- read.csv("Real Nest SEs.csv", header=T) #Comparison to standard errors from real data set

ggplot() +
  geom_line(data=ses, aes(x=Interval, y=Standard.Error, group=interaction(Nests, Scale), color=Nests, linetype=Scale), size=1) +
  scale_color_manual(name = "Starting nest number",
                     labels = c("40 nests", "100 nests", "400 nests"),
                     values = c("#C8102E", "orange4", "#F1BE48")) +
  scale_shape_manual(name = "Real nests",
                     labels = c("Dickcissel coarse", "Red-winged blackbird coarse", "Vesper sparrow coarse", 
                                "Dickcissel fine","Red-winged blackbird fine", "Vesper sparrow fine"),
                     values = c(15, 16, 17, 0, 1, 2)) +
  geom_point(data=real, aes(x=Interval, y=Standard.Error, group=interaction(Species, Scale), shape=interaction(Species, Scale)))+
  scale_y_continuous(limits=c(0,NA)) +
  theme(text=element_text(family="Times New Roman", size=12))+
  xlab("Visit interval") +
  ylab("Standard error")

# ggsave("Figure 4 larger font.png", device='png', width=5, height=5)
