
## ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ ##
#### For the "hatched" variable, a 1=failure to hatch and 0=successful hatch of at least one young ####
## ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ ##

library(ggplot2)
library(dplyr)
library(tidyr)
library(MASS)

rm(list = ls())
Nests <-read.csv('Nests.csv', header=T)

##~~~~~~~~~~~~~~~~~~~~~~~~~~~##
#### Simple Ratio Analysis ####
##~~~~~~~~~~~~~~~~~~~~~~~~~~~##

acceptors <- c("AMGO","COYE","DICK","GRSP","LASP","NOCA","RWBL","SOSP","VESP")
rejectors <- c("AMRO","BRTH","CHSP","GRCA","MESP")

Nests$Acceptor <- NA
Nests$Acceptor[which(Nests$Species %in% acceptors)] <- "Acceptor"
Nests$Acceptor[which(Nests$Species %in% rejectors)] <- "Rejector"
Nests$Acceptor <- as.factor(Nests$Acceptor)


rates <- subset(Nests, select=c(Species, Acceptor, ibutton_treatment_group, hatched))
rates <- rates[rates$ibutton_treatment_group=="Yes"|rates$ibutton_treatment_group=="No",]
rates <- rates[!is.na(rates$Acceptor),]
rates

summary(rates) #only 9% of nests were rejectors

rate.summary <- Nests %>%
  filter(ibutton_treatment_group %in% c("Yes", "No")) %>%
  filter(field_season=="2017") %>% # For use in summarizing results
  drop_na(Acceptor) %>%
  group_by(Species, ibutton_treatment_group, hatched) %>%
  mutate(hatched = if_else(hatched==0, "yes", "no")) %>%
  summarise(nest_count = n()) %>%
  pivot_wider(names_from=hatched,
              names_prefix="hatched_",
              values_from=nest_count,
              values_fill = 0) %>%
  dplyr::arrange(Species, desc(ibutton_treatment_group)) %>%
  dplyr::select(Species, ibutton_treatment_group, hatched_yes, hatched_no) %>%
  group_by(ibutton_treatment_group) %>% summarise(hatched_yes = sum(hatched_yes, hatched_no = sum(hatched_no)))

plyr::count(rates, vars=c("Species","ibutton_treatment_group", "hatched"))
plyr::count(rates, vars=c("ibutton_treatment_group", "hatched"))

# This is the loss rate calculation included in the 8/30/2021 revisions, not the one in "iButton loss rate.R"
loss.rate <- Nests %>%
  dplyr::select(Species, Acceptor, ibutton_treatment_group, hatched, field_season, ibuttondep, ibuttonret) %>%
  filter(Species %in% acceptors | Species %in% rejectors) %>%
  #filter(field_season=="2016") %>%
  filter(!(field_season=="2015" & !(Species %in% c("DICK","RWBL","VESP")))) %>%
  #group_by(Species, field_season, ibutton_treatment_group) %>%
  group_by(field_season, ibutton_treatment_group) %>%
  summarise(deployed = sum(ibuttondep),
            retrieved = sum(ibuttonret))

##~~~~~~~~~~~~~~~~~~~~~~~~~~##
#### Plotting Nest Counts ####
##~~~~~~~~~~~~~~~~~~~~~~~~~~##

nest.count <- count(rates, Species, ibutton_treatment_group)

nest.count$Species <- as.character(nest.count$Species)
nest.count$Species[nest.count$Species=="AMGO"] <- "American goldfinch"
nest.count$Species[nest.count$Species=="AMRO"] <- "American robin"
nest.count$Species[nest.count$Species=="BRTH"] <- "Brown thrasher"
nest.count$Species[nest.count$Species=="COYE"] <- "Common yellowthroat"
nest.count$Species[nest.count$Species=="DICK"] <- "Dickcissel"
nest.count$Species[nest.count$Species=="GRSP"] <- "Grasshopper sparrow"
nest.count$Species[nest.count$Species=="MESP"] <- "Eastern/western meadowlark"
nest.count$Species[nest.count$Species=="RWBL"] <- "Red-winged blackbird"
nest.count$Species[nest.count$Species=="SOSP"] <- "Song sparrow"
nest.count$Species[nest.count$Species=="VESP"] <- "Vesper sparrow"
nest.count$Species <- as.factor(nest.count$Species)

order <- aggregate(n~Species, data=nest.count, FUN=sum)
names(order)[names(order)=="n"] <- "total"
nest.count <- left_join(nest.count, order, by="Species")

nest.count <- transform(nest.count, Species=reorder(Species, -total))

names(nest.count)[names(nest.count)=="ibutton_treatment_group"] <- "iButton"


ggplot(nest.count, aes(x=Species, y=n, fill=iButton)) + 
  geom_col(position="stack") +
  scale_fill_manual(values=c("darkred", "goldenrod")) +
  ggtitle("Nest Counts by Species") +
  ylab("Number of Nests") +
  theme(plot.title=element_text(hjust=0.5), text=element_text(size=20)) +
  theme(axis.text.x=element_text(angle=55, size=16, hjust=1, vjust=1))

##~~~~~~~~~~~~~~~~##
#### GLM Models ####
##~~~~~~~~~~~~~~~~##

rates <- droplevels(rates)

model.list <- ls()
model.list <- NULL

# Did hatching rates differ between Accepting & Rejecting species, not accounting for iButtons?
model.list[["AccRej"]] <- glm(hatched ~ Acceptor, family=binomial(link='logit'), data=rates)
summary(model.list[["AccRej"]])
exp(cbind(coef(model.list[["AccRej"]]), confint(model.list[["AccRej"]], level=0.95)))  
confint(model.list[["AccRej"]], level=0.95, trace=T)

# Did hatching rates differ between accepting & rejecting species after accounting for iButtons
model.list[["iBut+AccRej"]] <- glm(hatched ~ ibutton_treatment_group+Acceptor, family=binomial(link='logit'), data=rates)
summary(model.list[["iBut+AccRej"]])
exp(cbind(coef(model.list[["iBut+AccRej"]]), confint(model.list[["iBut+AccRej"]], level=0.95))) 

model.list[["iBut*AccRej"]] <- glm(hatched ~ ibutton_treatment_group+Acceptor+ibutton_treatment_group*Acceptor, family=binomial(link='logit'), data=rates)
exp(cbind(coef(model.list[["AccRej"]]),      confint(model.list[["AccRej"]],      level=0.95)))  
exp(cbind(coef(model.list[["iBut*AccRej"]]), confint(model.list[["iBut*AccRej"]], level=0.95))) 

# Did hatching rates differ between treatment groups without accounting for accepting/rejecting status?
model.list[["iBut"]] <- glm(hatched ~ ibutton_treatment_group, family=binomial(link='logit'), data=rates)
summary(model.list[["iBut"]]) 
predict.glm(model.list[["iBut"]], type="response")
exp(cbind(coef(model.list[["iBut"]]), confint(model.list[["iBut"]], level=0.95)))  
confint(model.list[["iBut"]], level=0.95, trace=T)

# Null model
model.list[["Dot"]] <- glm(hatched ~ 1, family=binomial(link='logit'), data=rates)


# Predictions made on fully interactive model
d_predict <- expand.grid(Acceptor = c("Acceptor","Rejector"), ibutton_treatment_group = c("No","Yes"))
predict.table <- cbind(d_predict, predict(model.list[["iBut*AccRej"]], newdata = d_predict, type = "response", se.fit=T))

#write.csv(model.table, "simple iButton model table.csv", row.names=T)

m1 <- glm(hatched~ibutton_treatment_group*Acceptor, data=rates, family=binomial(link='logit'))
m2 <- glm(hatched~ibutton_treatment_group, data=rates, family=binomial(link='logit'))
m3 <- glm(hatched~ibutton_treatment_group*Acceptor, data=rates, family=quasibinomial(link='logit'))
summary(m1)
summary(m2)
summary(m3) #quasibinomial family allows estimation of dispersion parameter, here taken to be = 1.017, (as a ratio, 1 is ideal)

#estimating the over-dispersion parameter
with(m1, cbind(res.deviance = deviance, df = df.residual,
               p = pchisq(deviance, df.residual, lower.tail=FALSE)))


##~~~~~~~~~~~~~~~##
#### Contrasts ####
##~~~~~~~~~~~~~~~##

# Clarifying response variable
rates$hatched <- as.character(rates$hatched)
rates$hatched[rates$hatched=="0"] <- "Hatch"
rates$hatched[rates$hatched=="1"] <- "Failure"
rates$hatched <- as.factor(rates$hatched)

# Viewing success rate by species
rates %>% 
  group_by(ibutton_treatment_group, Species) %>%
  summarize(n = n(),
            y = sum(hatched=="Hatch"),
            p = y/n) %>%
  arrange(Species, ibutton_treatment_group)

# Selecting only those species which have a success and a failure for both treatments
subset <- rates %>% 
  mutate(iButton = 1*(ibutton_treatment_group=="Yes"),
         Species = factor(Species, levels = c("AMRO","MESP",
                                              "RWBL","DICK"))) %>%
  na.omit # remove all Species that are now NA

# Run a glm on the reduced dataset
m <- glm(hatched=="Hatch" ~ ibutton_treatment_group*Species, 
         data = subset, 
         family="binomial")
summary(m)

# Run a least-squares mean on the reduced dataset
ls <- lsmeans::lsmeans(m, ~ Species | ibutton_treatment_group,
              at = list(ibutton_treatment_group="Yes"))
summary(ls)

# Add a contrast to the lsmeans model
#                                               Rejectors Acceptors
#                                               AMRO MESP RWBL DICK
co <- lsmeans::contrast(ls, method = list(AccVsRej = c(  -1,  -1,   1,   1)/2))

# Does nest parasite accepting/rejecting status affect hatching success when added as a contrast?
co
ci <- confint(co)
ci

exp(c(ci$contrast, ci$ibutton_treatment_group, ci$estimate, ci$SE, ci$df, ci$asymp.LCL,ci$asymp.UCL))

exp(cbind(coef(model.list[["iBut*AccRej"]]), confint(model.list[["iBut*AccRej"]], level=0.95)))


##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~##
#### Correlations between parameters ####
##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~##

rm(list = ls())
Nests <-read.csv('Nests.csv', header=T)

Nests.cor <- subset(Nests, select=c(nest_name, iButton, BHCO, VegHeight, LiveForbsCover, Conceal, 
                                    Div, VOR, PchPAR, DTE, HighDiv20, HighDiv100))
row.names(Nests.cor) <- Nests.cor$nest_name

Nests.cor <- subset(Nests.cor, select=-c(nest_name))

correlations <- cor(Nests.cor)
correlations #r values

#write.csv(correlations, file = "Correlations.csv",row.names = T)
